@@ -31,6 +31,9 @@
 
 drop_summary <- function(data, last_col = NULL, section_min = 3) {
 
+  data <- data |>
+    dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
+
   if (is.null(last_col)) {
     while (ncol(data) > 0) {
       last_col <- ncol(data)
